OpenApiDartTemplate class

Generates a standalone REST API server (shelf_plus) whose endpoints match the OpenAPI specification already produced as .openapi.json.

Constructors

OpenApiDartTemplate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(List<Map<String, dynamic>> tools, int port, String address, Map<String, dynamic> openApiSpec, {bool logErrors = false}) String
Generates the .openapi.dart REST server source code.