maxCodeModeLength top-level constant
int
const maxCodeModeLength
Maximum allowed length for code mode scripts to prevent abuse.
Implementation
const maxCodeModeLength = 10000;
Maximum allowed length for code mode scripts to prevent abuse.
const maxCodeModeLength = 10000;