maxSearchQueryLength top-level constant
int
const maxSearchQueryLength
Maximum allowed length for search queries to prevent DoS.
Implementation
const maxSearchQueryLength = 500;
Maximum allowed length for search queries to prevent DoS.
const maxSearchQueryLength = 500;